/*
 * Strawberry Music Player
 * This file was part of Clementine.
 * Copyright 2012, David Sansome <me@davidsansome.com>
 * Copyright 2019-2021, Jonas Kvinge <jonas@jkvinge.net>
 *
 * Strawberry is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * Strawberry is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with Strawberry.  If not, see <http://www.gnu.org/licenses/>.
 *
 */

#ifndef MOODBARSETTINGSPAGE_H
#define MOODBARSETTINGSPAGE_H

#include "settingspage.h"

#include <QObject>
#include <QString>

class SettingsDialog;
class Ui_MoodbarSettingsPage;

class MoodbarSettingsPage : public SettingsPage {
  Q_OBJECT

 public:
  explicit MoodbarSettingsPage(SettingsDialog *dialog, QWidget *parent = nullptr);
  ~MoodbarSettingsPage() override;

  static const char *kSettingsGroup;

  void Load() override;
  void Save() override;
  void Cancel() override;

 private:
  static const int kMoodbarPreviewWidth;
  static const int kMoodbarPreviewHeight;

  void InitMoodbarPreviews();

  Ui_MoodbarSettingsPage *ui_;

  bool initialized_;
};

#endif  // MOODBARSETTINGSPAGE_H
